@@ -4,14 +4,21 @@ package # hide from PAUSE Indexer
 use strict;
 use warnings;
 
+use Scalar::Util 'blessed';
+use namespace::clean;
+
 sub mk_group_accessors {
     my ($class, $group, @cols) = @_;
 
     foreach my $col (@cols) {
-        my($accessor, $col) = ref $col ? @$col : (undef, $col);
+        my($accessor, $col) = ref $col eq 'ARRAY' ? @$col : (undef, $col);
 
         my($ro_meth, $wo_meth);
-        if( defined $accessor and ($accessor ne $col)) {
+        if (defined blessed $col and $col->isa('Class::DBI::Column')) {
+            $ro_meth = $col->accessor;
+            $wo_meth = $col->mutator;
+        }
+        elsif (defined $accessor and ($accessor ne $col)) {
             $ro_meth = $wo_meth = $accessor;
         }
         else {
@@ -35,8 +42,8 @@ sub mk_group_accessors {
 
 sub accessor_name_for {
     my ($class, $column) = @_;
-    if ($class->can('accessor_name')) { 
-        return $class->accessor_name($column) 
+    if ($class->can('accessor_name')) {
+        return $class->accessor_name($column)
     }
 
     return $column;
@@ -44,8 +51,8 @@ sub accessor_name_for {
 
 sub mutator_name_for {
     my ($class, $column) = @_;
-    if ($class->can('mutator_name')) { 
-        return $class->mutator_name($column) 
+    if ($class->can('mutator_name')) {
+        return $class->mutator_name($column)
     }
 
     return $column;
