@@ -7,6 +7,8 @@
     return <<"EOM";
 $snippet
 
+.NOTPARALLEL :
+
 create_distdir : check_create_distdir_prereqs clonedir_generate_files clonedir_post_generate_files fresh_manifest create_distdir_copy_manifested clonedir_cleanup_generated_files
 \t\$(NOECHO) \$(NOOP)
 
@@ -28,9 +30,15 @@ EOM
   }
 }
 
-# add an upload target check as a *preamble*
-# will ensure things being assembled in the right order
-preamble <<"EOP";
+# M::I inserts its own default postamble, so we can't easily override upload
+# but we can still hook postamble in EU::MM
+{
+  package MY;
+
+  sub postamble {
+    my $snippet = shift->SUPER::postamble(@_);
+    return <<"EOM";
+$snippet
 
 upload :: check_create_distdir_prereqs check_upload_dist_prereqs
 
@@ -39,7 +47,9 @@ check_upload_dist_prereqs :
   $mm_proto->oneliner("DBIx::Class::Optional::Dependencies->die_unless_req_ok_for(q(dist_upload))", [qw/-Ilib -MDBIx::Class::Optional::Dependencies/])
 ]}
 
-EOP
+EOM
+  }
+}
 
 # EU::MM BUG - workaround
 # somehow the init_PM of EUMM (in MM_Unix) interprets ResultClass.pod.proto
