@@ -1,9 +1,11 @@
 package # hide from PAUSE
     Log;
 
+use warnings;
+use strict;
+
 use base 'MyBase';
 
-use strict;
 use Time::Piece::MySQL;
 use POSIX;
 
@@ -15,6 +17,11 @@ __PACKAGE__->has_a(
   deflate        => 'mysql_datetime'
 );
 
+# Disables the implicit autoinc-on-non-supplied-pk behavior
+# (and the warning that goes with it)
+# This is the same behavior as it was pre 0.082900
+__PACKAGE__->column_info('id')->{is_auto_increment} = 0;
+
 __PACKAGE__->add_trigger(before_create => \&set_dts);
 __PACKAGE__->add_trigger(before_update => \&set_dts);
 
