@@ -1,3 +1,7 @@
 package DBICNSTest::ResultSet::C;
+
+use warnings;
+use strict;
+
 use base qw/DBIx::Class::ResultSet/;
 1;
