@@ -4,9 +4,9 @@ package #hide from pause
 use strict;
 use warnings;
 
+use base qw(DBICTest::Base DBIx::Class::Core);
+
 #use base qw/DBIx::Class::Relationship::Cascade::Rekey DBIx::Class::Core/;
-use base qw/DBIx::Class::Core/;
-use DBICTest::BaseResultSet;
 
 __PACKAGE__->table ('bogus');
 __PACKAGE__->resultset_class ('DBICTest::BaseResultSet');
