@@ -1,13 +1,19 @@
-package # hide from PAUSE 
+package # hide from PAUSE
     DBICTest::Schema::BooksInLibrary;
 
+use warnings;
+use strict;
+
 use base qw/DBICTest::BaseResult/;
 
 __PACKAGE__->table('books');
 __PACKAGE__->add_columns(
   'id' => {
+    # part of a test (auto-retrieval of PK regardless of autoinc status)
+    # DO NOT define
+    #is_auto_increment => 1,
+
     data_type => 'integer',
-    is_auto_increment => 1,
   },
   'source' => {
     data_type => 'varchar',
