@@ -1,6 +1,9 @@
-package # hide from PAUSE 
+package # hide from PAUSE
     DBICTest::Schema::Owners;
 
+use warnings;
+use strict;
+
 use base qw/DBICTest::BaseResult/;
 
 __PACKAGE__->table('owners');
@@ -16,6 +19,8 @@ __PACKAGE__->add_columns(
 );
 __PACKAGE__->set_primary_key('id');
 
+__PACKAGE__->add_unique_constraint(['name']);
+
 __PACKAGE__->has_many(books => "DBICTest::Schema::BooksInLibrary", "owner");
 
 1;
