@@ -1,6 +1,9 @@
-package # hide from PAUSE 
+package # hide from PAUSE
     DBICTest::Schema::TimestampPrimaryKey;
 
+use warnings;
+use strict;
+
 use base qw/DBICTest::BaseResult/;
 
 __PACKAGE__->table('timestamp_primary_key_test');
@@ -9,6 +12,7 @@ __PACKAGE__->add_columns(
   'id' => {
     data_type => 'timestamp',
     default_value => \'current_timestamp',
+    retrieve_on_insert => 1,
   },
 );
 
